@@ -2,135 +2,43 @@
  * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
- *
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
- *
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * 
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * 
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
- *
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
+ * 
  * @APPLE_LICENSE_HEADER_END@
  */
 
+// public
+#import <IOKit/firewire/IOConfigDirectory.h>
+#import <IOKit/firewire/IORemoteConfigDirectory.h>
+#import <IOKit/firewire/IOFireWireDevice.h>
+
+// private
+#import "FWDebugging.h"
+#include "IOConfigDirectoryIterator.h"
+
+// system
 #import <libkern/c++/OSIterator.h>
 #import <libkern/c++/OSData.h>
-#import <IOConfigDirectory.h>
-#import <IOFireWireDevice.h>
-
-#import "FWDebugging.h"
-#import "IORemoteConfigDirectory.h"
 
 static int findIndex(const UInt32* base, int size, int key,
                      UInt32 type = kInvalidConfigROMEntryType);
 
-
-class IOConfigDirectoryIterator : public OSIterator
-{
-    OSDeclareDefaultStructors(IOConfigDirectoryIterator)
-
-protected:
-    OSSet *	fDirectorySet;
-    OSIterator * fDirectoryIterator;
-	
-    virtual void free();
-
-public:
-    virtual IOReturn init(IOConfigDirectory *owner, UInt32 testVal, UInt32 testMask);
-    
-    virtual void reset();
-
-    virtual bool isValid();
-
-    virtual OSObject *getNextObject();
-};
-
-OSDefineMetaClassAndStructors(IOConfigDirectoryIterator, OSIterator)
-
-IOReturn IOConfigDirectoryIterator::init(IOConfigDirectory *owner,
-                                  		 UInt32 testVal, UInt32 testMask)
-{
-	IOReturn status = kIOReturnSuccess;
-	
-    if( !OSIterator::init() )
-        status = kIOReturnError;
-	
-	if( status == kIOReturnSuccess )
-	{
-		fDirectorySet = OSSet::withCapacity(2);
-		if( fDirectorySet == NULL )
-			status = kIOReturnNoMemory;
-	}
-	
-	int position = 0;
-	while( status == kIOReturnSuccess && position < owner->getNumEntries() ) 
-	{
-		UInt32 value;
-		IOConfigDirectory * next;
-		
-		status = owner->getIndexEntry( position, value );
-		if( status == kIOReturnSuccess && (value & testMask) == testVal ) 
-		{
-			status = owner->getIndexValue( position, next );
-			if( status == kIOReturnSuccess )
-			{
-				fDirectorySet->setObject( next );
-				next->release();
-			}
-		}
-		
-		position++;
-	}
-    
-	if( status == kIOReturnSuccess )
-	{
-		fDirectoryIterator = OSCollectionIterator::withCollection( fDirectorySet );
-		if( fDirectoryIterator == NULL )
-			status = kIOReturnNoMemory;
-	}
-	
-    return status;
-}
-
-void IOConfigDirectoryIterator::free()
-{
-	if( fDirectoryIterator != NULL )
-	{
-		fDirectoryIterator->release();
-		fDirectoryIterator = NULL;
-	}
-	
-	if( fDirectorySet != NULL )
-	{
-		fDirectorySet->release();
-		fDirectorySet = NULL;
-	}
-		
-    OSIterator::free();
-}
-
-void IOConfigDirectoryIterator::reset()
-{
-    fDirectoryIterator->reset();
-}
-
-bool IOConfigDirectoryIterator::isValid()
-{
-    return true;
-}
-
-OSObject *IOConfigDirectoryIterator::getNextObject()
-{
-	return fDirectoryIterator->getNextObject();
-}
-
 int findIndex(const UInt32* base, int size, int key, UInt32 type)
 {
     int i;
@@ -591,7 +499,7 @@ IOReturn IOConfigDirectory::getIndexValue(int index, OSData *&value)
 	if( status == kIOReturnSuccess )
 	{
 		data = lockData();
-		len = (data[offset] & kConfigLeafDirLength) >> kConfigLeafDirLengthPhase;
+		len = ((data[offset] & kConfigLeafDirLength) >> kConfigLeafDirLengthPhase);
 		unlockData();
 
 	//	FWKLOG(( "IOConfigDirectory::getIndexValue(OSData) updateROMCache( %ld, %d )\n", offset, len ));
@@ -665,7 +573,7 @@ IOReturn IOConfigDirectory::getIndexValue(int index, OSString *&value)
 		unlockData();
 	
 		// Check for silly length, people are careless with string data!
-		if( len > 256 ) 
+		if( (len * 4) > 256 ) 
         	status = kIOReturnBadArgument;
 	}
 
@@ -874,111 +782,3 @@ IOReturn IOConfigDirectory::getSubdirectories(OSIterator *&iterator)
                           kConfigEntryKeyType, iterator);
 }
 
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-
-OSDefineMetaClassAndStructors(IORemoteConfigDirectory, IOConfigDirectory)
-OSMetaClassDefineReservedUnused(IORemoteConfigDirectory, 0);
-OSMetaClassDefineReservedUnused(IORemoteConfigDirectory, 1);
-OSMetaClassDefineReservedUnused(IORemoteConfigDirectory, 2);
-
-
-bool
-IORemoteConfigDirectory::initWithOwnerOffset( IOFireWireROMCache *rom,
-                         int start, int type)
-{
-
-    // Do this first so that init can load ROM
-    fROM = rom;
-    fROM->retain();
-
-    if( !IOConfigDirectory::initWithOffset(start, type) ) 
-	{
-		fROM->release();
-		fROM = NULL;
-		
-        return false;       
-    }
-
-    return true;
-}
-
-void
-IORemoteConfigDirectory::free()
-{
-    if(fROM)
-        fROM->release();
-    IOConfigDirectory::free();
-}
-
-IOConfigDirectory *
-IORemoteConfigDirectory::withOwnerOffset( IOFireWireROMCache *rom,
-                                           int start, int type)
-{
-    IORemoteConfigDirectory *dir;
-
-    dir = new IORemoteConfigDirectory;
-    if( !dir )
-        return NULL;
-
-    if( !dir->initWithOwnerOffset(rom, start, type) ) 
-	{
-        dir->release();
-        dir = NULL;
-    }
-    return dir;
-}
-
-const UInt32 *IORemoteConfigDirectory::getBase()
-{
-    return ((const UInt32 *)fROM->getBytesNoCopy())+fStart+1;
-}
-
-IOReturn IORemoteConfigDirectory::update(UInt32 offset, const UInt32 *&romBase)
-{
-	// unsupported
-	
-	return kIOReturnError;
-}
-
-IOConfigDirectory *
-IORemoteConfigDirectory::getSubDir(int start, int type)
-{
-    return withOwnerOffset(fROM, start, type);
-}
-
-// lockData
-//
-//
-
-const UInt32 * IORemoteConfigDirectory::lockData( void )
-{
-	fROM->lock();
-	return (UInt32 *)fROM->getBytesNoCopy();
-}
-
-// unlockData
-//
-//
-
-void IORemoteConfigDirectory::unlockData( void )
-{
-	fROM->unlock();
-}
-
-// updateROMCache
-//
-//
-
-IOReturn IORemoteConfigDirectory::updateROMCache( UInt32 offset, UInt32 length )
-{
-	return fROM->updateROMCache( offset, length );
-}
-
-// checkROMState
-//
-//
-
-IOReturn IORemoteConfigDirectory::checkROMState( void )
-{
-	return fROM->checkROMState();
-}
