@@ -3,19 +3,22 @@
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
-* The contents of this file constitute Original Code as defined in and
-* are subject to the Apple Public Source License Version 1.1 (the
-* "License").  You may not use this file except in compliance with the
-* License.  Please obtain a copy of the License at
-* http://www.apple.com/publicsource and read it before using this file.
+* Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
 * 
-* This Original Code and all software distributed under the License are
-* distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+* This file contains Original Code and/or Modifications of Original Code
+* as defined in and that are subject to the Apple Public Source License
+* Version 2.0 (the 'License'). You may not use this file except in
+* compliance with the License. Please obtain a copy of the License at
+* http://www.opensource.apple.com/apsl/ and read it before using this
+* file.
+* 
+* The Original Code and all software distributed under the License are
+* distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
-* FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
-* License for the specific language governing rights and limitations
-* under the License.
+* FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+* Please see the License for the specific language governing rights and
+* limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
@@ -143,7 +146,7 @@ IOFWUserIsochPortProxy::allocatePort(IOFWSpeed speed, UInt32 chan)
 	IOReturn	result		= kIOReturnSuccess ;
 
 	lock() ;
-	
+    
 	if (!fPortAllocated)
 	{
 		if (!fPort)
@@ -911,32 +914,32 @@ IOFWUserLocalIsochPortProxy::getDCLSize(
 		case kDCLSendPacketOp:
 		case kDCLReceivePacketStartOp:
 		case kDCLReceivePacketOp:
-			result = sizeof(DCLTransferPacketStruct) ;
+			result = sizeof(DCLTransferPacket) ;
 			break ;
 			
 		case kDCLSendBufferOp:
 		case kDCLReceiveBufferOp:
-			result = sizeof(DCLTransferBufferStruct) ;
+			result = sizeof(DCLTransferBuffer) ;
 			break ;
 
 		case kDCLCallProcOp:
-			result = sizeof(DCLCallProcStruct) ;
+			result = sizeof(DCLCallProc) ;
 			break ;
 			
 		case kDCLLabelOp:
-			result = sizeof(DCLLabelStruct) ;
+			result = sizeof(DCLLabel) ;
 			break ;
 			
 		case kDCLJumpOp:
-			result = sizeof(DCLJumpStruct) ;
+			result = sizeof(DCLJump) ;
 			break ;
 			
 		case kDCLSetTagSyncBitsOp:
-			result = sizeof(DCLSetTagSyncBitsStruct) ;
+			result = sizeof(DCLSetTagSyncBits) ;
 			break ;
 			
 		case kDCLUpdateDCLListOp:
-			result = sizeof(DCLUpdateDCLListStruct) ;
+			result = sizeof(DCLUpdateDCLList) ;
 			break ;
 
 		case kDCLPtrTimeStampOp:
@@ -1092,6 +1095,12 @@ IOFWUserLocalIsochPortProxy::convertToKernelDCL(
 		IOLog("%s %u: couldn't get dclListMem\n", __FILE__, __LINE__) ;
 		result = kIOReturnNoMemory ;
 	}
+	
+	if ( kIOReturnSuccess == result )
+	{
+		result = dclListMem->prepare();
+	}
+	
 	if ( kIOReturnSuccess == result )
 	{
 		inDCLCommand->dclCommandList = new (DCLCommand*)[inDCLCommand->numDCLCommands] ;
@@ -1130,6 +1139,7 @@ IOFWUserLocalIsochPortProxy::convertToKernelDCL(
 	
 	if (dclListMem)
 	{
+		dclListMem->complete();
 		dclListMem->release() ;
 	}
 
