@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -47,9 +50,77 @@ extern const OSSymbol *gFireWire_GUID;
 extern const OSSymbol *gFireWireVendor_Name;
 extern const OSSymbol *gFireWireProduct_Name;
 
-class IOFireWireDevice ;
-class IOLocalConfigDirectory ;
-class IOFWLocalIsochPort ;
+class IOFireWireDevice;
+class IOLocalConfigDirectory;
+class IOFWLocalIsochPort;
+class IOFireWirePowerManager;
+class IOFireWireBus;
+
+#pragma mark -
+
+/*! 
+	@class IOFireWireBusAux
+*/
+
+class IOFireWireBusAux : public OSObject
+{
+    OSDeclareDefaultStructors(IOFireWireBusAux)
+
+	friend class IOFireWireBus;
+	
+protected:
+		
+	/*! 
+		@struct ExpansionData
+		@discussion This structure will be used to expand the capablilties of the class in the future.
+    */  
+	  
+    struct ExpansionData { };
+
+	/*! 
+		@var reserved
+		Reserved for future use.  (Internal use only)  
+	*/
+    
+	ExpansionData * reserved;
+	
+private:
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 0);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 1);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 2);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 3);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 4);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 5);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 6);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 7);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 8);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 9);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 10);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 11);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 12);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 13);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 14);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 15);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 16);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 17);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 18);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 19);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 20);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 21);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 22);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 23);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 24);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 25);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 26);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 27);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 28);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 29);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 30);
+    OSMetaClassDeclareReservedUnused(IOFireWireBusAux, 31);
+	
+};
+
+#pragma mark -
 
 class IOFireWireBus : public IOService
 {
@@ -57,8 +128,6 @@ class IOFireWireBus : public IOService
 
 public:
 
-static const IORegistryPlane * gIOFireWirePlane;
-
     typedef void (CallUserProc)(void *refcon, void * userProc, void * dclCommand);
     typedef struct _DCLTaskInfo {
         task_t fTask;	// Task DCL addresses are valid in
@@ -70,6 +139,10 @@ static const IORegistryPlane * gIOFireWirePlane;
         void *fCallRefCon;	// Refcon for user call
     } DCLTaskInfo;
 
+	static const IORegistryPlane * gIOFireWirePlane;
+
+	IOFireWireBusAux * fAuxiliary;
+
     // Create an Isochronous Channel object
     virtual IOFWIsochChannel *createIsochChannel(
         bool doIRM, UInt32 bandwidth, IOFWSpeed prefSpeed,
@@ -130,16 +203,23 @@ static const IORegistryPlane * gIOFireWirePlane;
     virtual IOFWAsyncStreamCommand *createAsyncStreamCommand( UInt32 generation,
     			UInt32 channel, UInt32 sync, UInt32 tag, IOMemoryDescriptor *hostMem,
 				UInt32 size, int speed,FWAsyncStreamCallback completion=NULL, void *refcon=NULL) = 0;
-    
+
+	virtual UInt32 hopCount(UInt16 nodeAAddress, UInt16 nodeBAddress ) = 0;
+	virtual UInt32 hopCount(UInt16 nodeAAddress ) = 0;
+	virtual IOFireWirePowerManager * getBusPowerManager( void ) = 0;
+
+protected:
+	virtual IOFireWireBusAux * createAuxiliary( void ) = 0;
+	
 private:
     OSMetaClassDeclareReservedUsed(IOFireWireBus, 0);
     OSMetaClassDeclareReservedUsed(IOFireWireBus, 1);
     OSMetaClassDeclareReservedUsed(IOFireWireBus, 2);
     OSMetaClassDeclareReservedUsed(IOFireWireBus, 3);
-    OSMetaClassDeclareReservedUnused(IOFireWireBus, 4);
-    OSMetaClassDeclareReservedUnused(IOFireWireBus, 5);
-    OSMetaClassDeclareReservedUnused(IOFireWireBus, 6);
-    OSMetaClassDeclareReservedUnused(IOFireWireBus, 7);
+    OSMetaClassDeclareReservedUsed(IOFireWireBus, 4);
+    OSMetaClassDeclareReservedUsed(IOFireWireBus, 5);
+    OSMetaClassDeclareReservedUsed(IOFireWireBus, 6);
+    OSMetaClassDeclareReservedUsed(IOFireWireBus, 7);
 
 };
 
